radbelt - Functions supporting radiation belt diffusion codes — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »

# radbelt - Functions supporting radiation belt diffusion codes

Functions supporting radiation belt diffusion codes

Authors: Josef Koller Institution: Los Alamos National Laboratory Contact: jkoller@lanl.gov

Copyright 2010 Los Alamos National Security, LLC.

Classes

`RBmodel`([grid, NL, const_kp]) | 1-D Radial diffusion class

Functions

`get_modelop_L`(f, L, Dm_old, Dm_new, Dp_old, ...) | Advance the distribution function, f, discretized into the Lgrid, L, forward in time by a timestep, Tdelta.
`diff_LL`(r, grid, f, Tdelta, Telapsed[, params]) | calculate the diffusion in L at constant mu,K coordinates
`get_local_accel`(Lgrid, params[, SRC_model]) | calculate the diffusion coefficient D_LL

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »